package com.ruoyi.project.training.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.training.mapper.TSkillevaluationMapper;
import com.ruoyi.project.training.domain.TSkillevaluation;
import com.ruoyi.project.training.service.ITSkillevaluationService;

import javax.annotation.Resource;

/**
 * 岗位人员技能评估Service业务层处理
 *
 * @author ruoyi
 * @date 2020-12-08
 */
@Service
public class TSkillevaluationServiceImpl implements ITSkillevaluationService
{
    @Resource
    private TSkillevaluationMapper tSkillevaluationMapper;

    /**
     * 查询岗位人员技能评估
     *
     * @param id 岗位人员技能评估ID
     * @return 岗位人员技能评估
     */
    @Override
    public TSkillevaluation selectTSkillevaluationById(Long id)
    {
        return tSkillevaluationMapper.selectTSkillevaluationById(id);
    }

    /**
     * 查询岗位人员技能评估列表
     *
     * @param tSkillevaluation 岗位人员技能评估
     * @return 岗位人员技能评估
     */
    @Override
    public List<TSkillevaluation> selectTSkillevaluationList(TSkillevaluation tSkillevaluation)
    {
        return tSkillevaluationMapper.selectTSkillevaluationList(tSkillevaluation);
    }

    /**
     * 新增岗位人员技能评估
     *
     * @param tSkillevaluation 岗位人员技能评估
     * @return 结果
     */
    @Override
    public int insertTSkillevaluation(TSkillevaluation tSkillevaluation)
    {
        return tSkillevaluationMapper.insertTSkillevaluation(tSkillevaluation);
    }

    /**
     * 修改岗位人员技能评估
     *
     * @param tSkillevaluation 岗位人员技能评估
     * @return 结果
     */
    @Override
    public int updateTSkillevaluation(TSkillevaluation tSkillevaluation)
    {
        return tSkillevaluationMapper.updateTSkillevaluation(tSkillevaluation);
    }

    /**
     * 批量删除岗位人员技能评估
     *
     * @param ids 需要删除的岗位人员技能评估ID
     * @return 结果
     */
    @Override
    public int deleteTSkillevaluationByIds(Long[] ids)
    {
        return tSkillevaluationMapper.deleteTSkillevaluationByIds(ids);
    }

    /**
     * 删除岗位人员技能评估信息
     *
     * @param id 岗位人员技能评估ID
     * @return 结果
     */
    @Override
    public int deleteTSkillevaluationById(Long id)
    {
        return tSkillevaluationMapper.deleteTSkillevaluationById(id);
    }
}
